#!/bin/bash

function _erase(){
	dd if=/dev/zero of=$1 bs=512 count=1
	parted -s $1 mklabel msdos
	parted -s $1 mkpart primary $3 1 100%
	wipefs -a $2 --force
}

function _umount(){
	USB=$(cat /etc/mtab | grep "$1" | awk '{print $1}')
	if [ "$USB" != "" ]; then
		umount $USB
	fi
}

function _close(){

	windowID="$(xprop -root '\t$0' _NET_ACTIVE_WINDOW | cut -f 2)"

	if [ "$1" == "0" ]; then
		kdialog --attach="$windowID" --msgbox $"Sua unidade USB foi formatada com sucesso!"
		echo "<META http-equiv=\"refresh\" content=\"0;URL=/usr/share/bigbashview/close.sh\">"
	else
		kdialog --attach="$windowID" --error $"A formatação não pode ser concluída!\nVerifique sua unidade USB e tente novamente!"
		echo "<META http-equiv=\"refresh\" content=\"0;URL=index.sh.htm\">"
	fi
}

DEV="/dev/$1"
PART=$DEV"1"
TMP="/tmp/$1-btrfs"

#Confere o primeiro parametro informado com as opções a seguir, exemplo de uso: ./script start
case "$2" in

    fat32)
		_umount $1
		_erase $DEV $PART fat32	
		mkfs.fat -F32 -I -n $3 $PART
		_close "$?"	
    ;;

    ntfs)
		_umount $1
		_erase $DEV $PART NTFS
		mkntfs -Q -v -F -L $3 $PART
		_close "$?"
    ;;

    exfat)
		_umount $1
		_erase $DEV $PART NTFS
		mkfs.exfat -n $3 $PART
		_close "$?"
    ;;
    
    btrfs)
		_umount $1
		_erase $DEV $PART btrfs
		mkfs.btrfs -f -L $3 $PART
		mkdir -p $TMP
		mount $PART $TMP
		btrfs property set $TMP compression zstd
		chmod 777 $TMP
		umount $TMP
		rm -rf $TMP
		_close "$?"
    ;;

esac
